<template>
  <div class="p-3 pb-5 mb-5">
    <!-- بخش موجودی کیف پول -->
    <div class="row g-4 mb-4">
      <!-- کارت موجودی -->
      <div class="col-lg-6">
        <div class="card border-0 shadow-sm rounded-4 h-100">
          <div class="card-body p-4">
            <div class="d-flex align-items-center justify-content-between mb-4">
              <h5 class="mb-0 fw-bold text-default">
                <i class="fas fa-wallet ms-2"></i>
                {{ t("account.wallet.title") }}
              </h5>
            </div>

            <!-- دایره موجودی -->
            <div class="text-center my-3 my-md-4">
              <div class="position-relative d-inline-block">
                <div class="wallet-circle p-3 p-md-4 rounded-circle d-flex align-items-center justify-content-center" :class="conditionList()">
                  <div>
                    <div class="fs-6 text-muted mb-2">{{ t("account.wallet.balance") }}</div>
                    <div class="fw-bold" style="font-size: clamp(1.5rem, 4.5vw, 1rem);">
                      {{ data.wallet.balance }} <small class="fs-6">{{ t('global.currency') }}</small>
                    </div>
                  </div>
                </div>
              </div>
            </div>

            <hr class="my-4 border-2 opacity-10">

            <!-- فرم شارژ کیف پول -->
            <div>
              <h6 class="fw-bold mb-3 text-default">
                <i class="fas fa-plus-circle me-2"></i>
                {{ t("account.wallet.charge_section.title") }}
              </h6>
              <form @submit.prevent="submitPayment">
                <div class="mb-3">
                  <label for="amount" class="form-label text-muted">
                    {{ t("account.wallet.charge_section.input_label") }}
                  </label>
                  <form-price id="amount" v-model="data.amount"
                              :placeholder="t('account.wallet.charge_section.input_placeholder')"/>
                  <small class="text-muted mt-1 d-block">{{
                      t("account.wallet.charge_section.min_notice", {price: $helper?.getCurrency(data.min_price)})
                    }}</small>
                </div>
                <button
                    type="submit"
                    class="btn w-100 py-3 fw-bold rounded-3 btn-default"
                    :disabled="!isValidAmount"
                    :class="{'btn-loading': data.payment_loaded}"
                >
                  <span v-if="!data.payment_loaded">
                    <i class="fas fa-credit-card me-2"></i>{{ t("account.wallet.charge_section.submit") }}
                  </span>
                  <span v-else>
                    <span class="spinner-border spinner-border-sm me-2" role="status" aria-hidden="true"></span>
                    {{ t("account.wallet.charge_section.processing") }}
                  </span>
                </button>
              </form>
            </div>
          </div>
        </div>
      </div>

      <!-- بخش پیشنهاد مبالغ سریع -->
      <div class="col-lg-6">
        <div class="card border-0 shadow-sm rounded-4 h-100">
          <div class="card-body p-4 d-flex flex-column">
            <h5 class="fw-bold mb-4 text-default">
              <i class="fas fa-bolt me-2"></i>
              {{ t("account.wallet.quick_charge.title") }}
            </h5>

            <div class="row g-2 g-md-3 mb-4">
              <div class="col-6 col-md-6 col-lg-6 col-xl-3">
                <button
                    class="btn w-100 py-2 py-md-3 rounded-3 amount-btn text-default btn-outline-default border-default"
                    @click="setAmount(50000)">
                  {{ t("account.wallet.quick_charge.amount", {price: $helper?.getCurrency(50000)}) }}
                </button>
              </div>
              <div class="col-6 col-md-6 col-lg-6 col-xl-3">
                <button
                    class="btn w-100 py-2 py-md-3 rounded-3 amount-btn text-default btn-outline-default border-default"
                    @click="setAmount(100000)">
                  {{ t("account.wallet.quick_charge.amount", {price: $helper?.getCurrency(100000)}) }}
                </button>
              </div>
              <div class="col-6 col-md-6 col-lg-6 col-xl-3">
                <button
                    class="btn w-100 py-2 py-md-3 rounded-3 amount-btn text-default btn-outline-default border-default"
                    @click="setAmount(200000)">
                  {{ t("account.wallet.quick_charge.amount", {price: $helper?.getCurrency(200000)}) }}
                </button>
              </div>
              <div class="col-6 col-md-6 col-lg-6 col-xl-3">
                <button
                    class="btn w-100 py-2 py-md-3 rounded-3 amount-btn text-default btn-outline-default border-default"
                    @click="setAmount(500000)">
                  {{ t("account.wallet.quick_charge.amount", {price: $helper?.getCurrency(500000)}) }}
                </button>
              </div>
            </div>

            <div class="mt-auto">
              <div class="alert alert-light rounded-3" style="border-color: rgba(255, 152, 0, 0.25);">
                <div class="d-flex align-items-center">
                  <i class="fas fa-info-circle me-2 text-default"></i>
                  <small>{{ t("account.wallet.quick_charge.note") }}</small>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>

    <div class="d-flex align-items-center justify-content-between mb-3">
      <h5 class="mb-0 fw-bold" style="color: #ff9800;">
        <i class="fas fa-file-alt me-2"></i>
        {{ t("account.wallet.reports.title") }}
      </h5>
    </div>

    <div class="transactions-list">
      <template v-if="data.loaded">
        <template v-if="data.wallet.reports.length > 0">
          <div class="card mb-3 border-0 shadow-sm rounded-3"
               v-for="(report, index) in data.wallet.reports"
               :key="report.id"
               :class="report.method === 'plus' ? 'bg-success bg-opacity-10' : 'bg-danger bg-opacity-10'"
          >
            <div class="card-body">
              <div class="d-flex justify-content-between align-items-start mb-2">
                <div>
                <span class="ms-2 font-size-14">
                  <i :class="report.method === 'plus' ? 'fas fa-plus-circle' : 'fas fa-minus-circle'" class="me-1"></i>
                  {{ report.description }}
                </span>
                </div>
                <span class="fw-bold mx-1">
                {{ report.price }}
              </span>
              </div>
              <div class="d-flex justify-content-end align-items-center">
                <small class="text-muted font-size-12" dir="ltr">
                  <i class="fas fa-clock me-1"></i>
                  {{ report.date }}
                </small>
              </div>
            </div>
          </div>
        </template>
        <template v-else>
          <template v-if="data.loaded">
            <div class="row mt-5">
              <div class="col-12">
                <div class="d-flex align-items-center justify-content-center flex-column py-1">
                  <i class="icon icon-regular-bookmark-times text-muted" style="font-size: 3rem;"></i>
                  <h5 class="mt-3  text-center text-secondary">{{ t("account.wallet.empty.title") }}</h5>
                  <p class="text-muted text-center">{{ t("account.wallet.empty.description") }}</p>
                </div>
              </div>
            </div>
          </template>
        </template>
      </template>

      <template v-else>
        <shimmer v-for="i in 15" :key="i" height="100" custom-class="my-2"/>
      </template>
    </div>

    <!-- Modal -->
    <modal-payment v-model:show="data.showPayment" :url="data.url"/>
  </div>
</template>

<script setup>
import {useI18n} from 'vue-i18n';
import {ref, computed, onMounted, reactive} from 'vue';
import {useAuthStore} from '~/stores/auth';

definePageMeta({
  layout: "default",
  middleware: ['auth']
})

// Variable
const {t} = useI18n();
const {$api, $helper} = useNuxtApp();
const auth = useAuthStore();

// Data
const data = reactive({
  payment_loaded: false,
  loaded: false,
  showPayment: false,
  amount: "",
  wallet: {
    balance: '0',
    reports: []
  },
  url: "",
  min_price: "10000"
});

const isValidAmount = computed(() => {
  const num = parseInt(data.amount.replace(/,/g, ''));
  return !isNaN(num) && num >= data.min_price;
});

const conditionList = () => {
  let wallet = parseFloat(data.wallet.balance.replaceAll(',',''))
  return [
    {'success': wallet > 100000},
    {'warning': wallet > 50000 && wallet <= 100000},
    {'danger': wallet >= 0 && wallet <= 50000},
  ];
}

// Actions
const getData = async () => {
  await $api.post('/user/wallet', {}).then((value) => {
    if (value.data.status) {
      data.wallet = value.data.data;

      setTimeout(() => {
        data.loaded = true;
      }, 500)
    }
  })
};

const setAmount = (value) => {
  data.amount = value.toString();
};

const submitPayment = async () => {
  if (!isValidAmount) return;
  data.payment_loaded = true;

  await $api.post('/payment/wallet', {
    price: data.amount.replaceAll(',', ''),
    platform: 'app'
  }).then((value) => {
    if (value.data?.status) {
      data.url = value.data.data.url;
      data.showPayment = true;
      data.payment_loaded = false;
    }
  })
};

// Life Cycle
onMounted(() => {
  getData();
});

</script>

<style scoped>

</style>